@@ -9,39 +9,42 @@
 #'
 #' @return returns a single object containing the data to be analyzed (usually a
 #'   \code{vector}, \code{matrix}, or \code{data.frame}),
-#'   or a list with the elements \code{'dat'} and \code{'parameters'}.
-#'
-#'   If a list is returned the \code{'dat'} element should be the observed data object while the
-#'   \code{'parameters'} element should be a named list containing the simulated parameters
-#'   (if there are any. Otherwise, this could just be an empty list),
-#'   or any other objects that would be useful
-#'   in the \code{\link{Analyse}} and \code{\link{Summarise}} functions. If, on the other hand,
-#'   the objects are only useful in the \code{\link{Analyse}} function and NOT
-#'   \code{\link{Summarise}} then simply adding \code{\link{attributes}} to the returned object
-#'   is sufficent (and requires less RAM)
+#'   or \code{list})
 #'
 #' @aliases Generate
 #'
-#' @seealso \code{\link{add_missing}}
+#' @seealso \code{\link{add_missing}}, \code{\link{Attach}}
 #'
 #' @examples
 #' \dontrun{
 #'
 #' mygenerate <- function(condition, fixed_objects = NULL){
-#'
-#'     #require packages/define functions if needed, or better yet index with the :: operator
-#'
 #'     N1 <- condition$sample_sizes_group1
 #'     N2 <- condition$sample_sizes_group2
 #'     sd <- condition$standard_deviations
 #'
 #'     group1 <- rnorm(N1)
 #'     group2 <- rnorm(N2, sd=sd)
-#'     dat <- data.frame(group = c(rep('g1', N1), rep('g2', N2)), DV = c(group1, group2))
-#'     pars <- list(random_number = rnorm(1)) # just a silly example of a simulated parameter
+#'     dat <- data.frame(group = c(rep('g1', N1), rep('g2', N2)),
+#'                       DV = c(group1, group2))
+#'     # just a silly example of a simulated parameter
+#'     pars <- list(random_number = rnorm(1))
 #'
-#'     #could just use return(dat) if no parameters should be tracked for Summerise
-#'     return(list(dat=dat, parameters=pars))
+#'     list(dat=dat, parameters=pars)
+#' }
+#'
+#' # similar to above, but using the Attach() function instead of indexing
+#' mygenerate <- function(condition, fixed_objects = NULL){
+#'     Attach(condition)
+#'     N1 <- sample_sizes_group1
+#'     N2 <- sample_sizes_group2
+#'     sd <- standard_deviations
+#'
+#'     group1 <- rnorm(N1)
+#'     group2 <- rnorm(N2, sd=sd)
+#'     dat <- data.frame(group = c(rep('g1', N1), rep('g2', N2)),
+#'                       DV = c(group1, group2))
+#'     dat
 #' }
 #'
 #' mygenerate2 <- function(condition, fixed_objects = NULL){
@@ -52,13 +55,10 @@
 #'
 #' mygenerate3 <- function(condition, fixed_objects = NULL){
 #'     mu <- sample(c(-1,0,1), 1)
-#'     dat <- rnorm(100, mu)
-#'     attr(dat, 'mu') <- mu    # store mu as an attribute 'mu'
+#'     dat <- data.frame(DV = rnorm(100, mu))
 #'     dat
 #' }
 #'
-#' # in the Analyse function, use attr(dat, 'mu') to pull out the mu object for further use
-#'
 #' }
 #'
 Generate <- function(condition, fixed_objects = NULL) NULL
@@ -76,27 +76,25 @@ Generate <- function(condition, fixed_objects = NULL) NULL
 #'
 #' The use of \code{\link{try}} functions is generally not required because the function
 #' is internally wrapped in a \code{\link{try}} call. Therefore, if a function stops early
-#' then this will cause the function to halt iternally, the message which triggered the \code{\link{stop}}
+#' then this will cause the function to halt internally, the message which triggered the \code{\link{stop}}
 #' will be recorded, and \code{\link{Generate}} will be called again to obtain a different dataset.
 #' That being said, it may be useful for users to throw their own \code{\link{stop}} commands if the data
 #' should be redrawn for other reasons (e.g., a model terminated correctly but the maximum number of
 #' iterations were reached).
 #'
 #' @param dat the \code{dat} object returned from the \code{\link{Generate}} function
-#'   (usually a \code{data.frame}, \code{matrix}, or \code{vector}).
-#'
-#' @param parameters the (optional) list object named 'parameters' returned from the
-#'   \code{\link{Generate}} function when a list is returned. Otherwise, this will be an just an
-#'   empty list
+#'   (usually a \code{data.frame}, \code{matrix}, \code{vector}, or \code{list})
 #'
 #' @param condition a single row from the design input (as a \code{data.frame}), indicating the
 #'   simulation conditions
 #'
 #' @param fixed_objects object passed down from \code{\link{runSimulation}}
 #'
-#' @return returns a named \code{numeric} vector with the values of interest (e.g., p-values,
-#'   effects sizes, etc), or a \code{list} containing values of interest (e.g., separate matrix
-#'   and vector of parameter estimates corresponding to elements in \code{parameters})
+#' @return returns a named \code{numeric} vector or \code{data.frame} with the values of interest
+#'   (e.g., p-values, effects sizes, etc), or a \code{list} containing values of interest
+#'   (e.g., separate matrix and vector of parameter estimates corresponding to elements in
+#'   \code{parameters}). If a \code{data.frame} is returned with more than 1 row then these
+#'   objects will be wrapped into \code{list} objects
 #'
 #' @seealso \code{\link{stop}}
 #' @aliases Analyse
@@ -104,7 +102,7 @@ Generate <- function(condition, fixed_objects = NULL) NULL
 #' @examples
 #' \dontrun{
 #'
-#' myanalyse <- function(condition, dat, fixed_objects = NULL, parameters = NULL){
+#' myanalyse <- function(condition, dat, fixed_objects = NULL){
 #'
 #'     # require packages/define functions if needed, or better yet index with the :: operator
 #'     require(stats)
@@ -123,7 +121,7 @@ Generate <- function(condition, fixed_objects = NULL) NULL
 #' }
 #'
 #' }
-Analyse <- function(condition, dat, fixed_objects = NULL, parameters = NULL) NULL
+Analyse <- function(condition, dat, fixed_objects = NULL) NULL
 
 
 
@@ -136,18 +134,19 @@ Analyse <- function(condition, dat, fixed_objects = NULL, parameters = NULL) NUL
 #' estimates such as RMSE, bias, Type I error rates, coverage rates, etc.
 #'
 #' @param results a \code{data.frame} (if \code{Analyse} returned a numeric vector) or a \code{list}
-#'   (if \code{Analyse} returned a list) containing the simulation results from \code{\link{Analyse}},
+#'   (if \code{Analyse} returned a list or multi-rowed data.frame) containing the analysis
+#'   results from \code{\link{Analyse}},
 #'   where each cell is stored in a unique row/list element
-#' @param parameters_list an (optional) list containing all the 'parameters' elements generated
-#'   from \code{\link{Generate}}, where each repetition is stored in a unique element. If a \code{list}
-#'   was not returned from \code{\link{Generate}} then this will be \code{NULL}
+#'
 #' @param condition a single row from the \code{design} input from \code{\link{runSimulation}}
 #'   (as a \code{data.frame}), indicating the simulation conditions
+#'
 #' @param fixed_objects object passed down from \code{\link{runSimulation}}
 #'
 #' @aliases Summarise
 #'
-#' @return must return a named \code{numeric} vector with the desired meta-simulation results
+#' @return must return a named \code{numeric} vector or \code{data.frame}
+#'   with the desired meta-simulation results
 #'
 #' @seealso \code{\link{bias}}, \code{\link{RMSE}}, \code{\link{RE}}, \code{\link{EDR}},
 #'   \code{\link{ECR}}, \code{\link{MAE}}
@@ -155,30 +154,19 @@ Analyse <- function(condition, dat, fixed_objects = NULL, parameters = NULL) NUL
 #' @examples
 #' \dontrun{
 #'
-#' mysummarise <- function(condition, results, fixed_objects = NULL, parameters_list = NULL){
-#'
-#'     #convert to matrix for convenience (if helpful)
-#'     cell_results <- do.call(rbind, results)
-#'
-#'     # silly test for bias and RMSE of a random number from 0
-#'     pop_value <- 0
-#'     bias.random_number <- bias(sapply(parameters_list, function(x) x$random_number), pop_value)
-#'     RMSE.random_number <- RMSE(sapply(parameters_list, function(x) x$random_number), pop_value)
+#' mysummarise <- function(condition, results, fixed_objects = NULL){
 #'
 #'     #find results of interest here (alpha < .1, .05, .01)
-#'     nms <- c('welch', 'independent')
-#'     lessthan.05 <- EDR(results[,nms], alpha = .05)
+#'     lessthan.05 <- EDR(results, alpha = .05)
 #'
 #'     # return the results that will be appended to the design input
-#'     ret <- c(bias.random_number=bias.random_number,
-#'              RMSE.random_number=RMSE.random_number,
-#'              lessthan.05=lessthan.05)
-#'     return(ret)
+#'     ret <- c(lessthan.05=lessthan.05)
+#'     ret
 #' }
 #'
 #' }
 #'
-Summarise <- function(condition, results, fixed_objects = NULL, parameters_list = NULL) NULL
+Summarise <- function(condition, results, fixed_objects = NULL) NULL
 
 
 #=================================================================================================#
@@ -250,30 +238,32 @@ mainsim <- function(index, condition, generate, analyse, fixed_objects, max_erro
             }
             saveRDS(simlist, filename)
         }
-        if(is.data.frame(simlist) || !is.list(simlist)) simlist <- list(dat=simlist)
-        if(length(names(simlist)) > 1L)
-            if(!all(names(simlist) %in% c('dat', 'parameters')))
-                stop('generate() did not return a list with elements \'dat\' and \'parameters\'', call.=FALSE)
         Warnings <- NULL
         wHandler <- function(w) {
             Warnings <<- c(Warnings, list(w))
             invokeRestart("muffleWarning")
         }
-        res <- try(withCallingHandlers(analyse(dat=simlist$dat, parameters=simlist$parameters, condition=condition,
+        res <- try(withCallingHandlers(analyse(dat=simlist, condition=condition,
                            fixed_objects=fixed_objects), warning=wHandler), silent=TRUE)
         if(!is.null(Warnings)){
             Warnings <- sapply(1L:length(Warnings), function(i, Warnings) {
                 paste0('Warning in ', deparse(Warnings[[i]]$call), ' : ', Warnings[[i]]$message)
             }, Warnings)
         }
+        if(any(is.na(res))){
+            NA_names <- names(res)[is.na(res)]
+            res <- try(stop(sprintf('The following return NA/NaN and required redrawing: %s',
+                                    paste(NA_names, sep=',')),
+                            call.=FALSE), silent=TRUE)
+        }
 
         # if an error was detected in compute(), try again
         if(is(res, 'try-error')){
             try_error <- c(try_error, res[1L])
             if(length(try_error) == max_errors){
                 res[1L] <-
-                    gsub('Error in analyse\\(dat = simlist\\$dat, parameters = simlist\\$parameters, condition = condition,  : \\n  ',
-                         replacement = 'Manual Error : ', res[1L])
+                    gsub('Error in analyse\\(dat = simlist, condition = condition, fixed_objects = fixed_objects) : \\n  ',
+                         replacement = 'Error : ', res[1L])
                 stop(paste0('Row ', condition$ID, ' in design was terminated because it had ', max_errors,
                             ' consecutive errors. \n\nLast error message was: \n\n  ', res[1L]), call.=FALSE)
             }
@@ -282,9 +272,8 @@ mainsim <- function(index, condition, generate, analyse, fixed_objects, max_erro
         if(!is.list(res) && !is.numeric(res))
             stop('analyse() did not return a list or numeric vector', call.=FALSE)
 
-        ret <- list(result=res, parameters=simlist$parameters)
-        attr(ret, 'try_errors') <- try_error
-        attr(ret, 'warnings') <- Warnings
-        return(ret)
+        attr(res, 'try_errors') <- try_error
+        attr(res, 'warnings') <- Warnings
+        return(res)
     }
 }
